@@ -8,7 +8,7 @@ __all__ = ["export", "export_subclass", "export_instance"]
 
 
 @lru_cache(maxsize=1)
-def _get_cache():
+def __get_cache():
     return {}
 
 
@@ -42,18 +42,8 @@ def export(
 
     if package is None:
         package = _locals["__name__"]
-        # for frame in reversed(outer_frames):
-        #     if "__file__" in frame.frame.f_globals:
-        #         call_dir = Path(frame.frame.f_globals["__file__"]).resolve().parent
-        #         if current_dir.as_posix().startswith(call_dir.as_posix()):
-        #             package = frame.frame.f_globals["__package__"]
-        #             subpackage = (
-        #                 current_dir.relative_to(call_dir).as_posix().replace("/", ".")
-        #             )
-        #             package = f"{package}.{subpackage}" if package else subpackage
-        #             break
 
-    cached = _get_cache()
+    cached = __get_cache()
     unique_key = (current_file.as_posix(), call_frame.frame.f_lineno)
 
     if unique_key in cached:
