@@ -201,9 +201,9 @@ def asdict(obj: Dataclass, by_alias: bool = True, parser: Parser = DictParser())
         val = getattr(obj, key)
         if isinstance(val, Dataclass):
             val = asdict(val, by_alias=by_alias, parser=parser)
-        elif isinstance(obj, (list, set, tuple)):
+        elif isinstance(val, (list, set, tuple)):
             val = type(val)(asdict(elem) for elem in val)
-        elif isinstance(obj, dict):
+        elif isinstance(val, dict):
             val = {_key: asdict(_val) for _key, _val in val.items()}
         else:
             pass
